@@ -13,7 +13,7 @@ class ExpansionTool(Tool):
                          True)
 
     def applyChanges(self, inp, motor, simulation):
-        k = motor.propellant.props['k'].getValue()
+        _, _, k, _, _ = motor.propellant.getCombustionProperties(simulation.getAveragePressure())
         pRatio = self.preferences.general.props['ambPressure'].getValue() / simulation.getAveragePressure()
 
         aRatio = ((k + 1) / 2) ** (1 / (k - 1)) * pRatio ** (1 / k) * (((k + 1) / (k - 1)) * (1 - (pRatio ** ((k - 1) / k)))) ** 0.5
