@@ -1,4 +1,4 @@
-from PyQt5.QtWidgets import QDialog
+from PyQt5.QtWidgets import QDialog, QApplication
 from ..views.AboutDialog_ui import Ui_AboutDialog
 
 
@@ -8,4 +8,6 @@ class AboutDialog(QDialog):
         self.ui = Ui_AboutDialog()
         self.ui.setupUi(self)
 
+        self.setWindowIcon(QApplication.instance().icon)
+
         self.ui.labelText.setText(self.ui.labelText.text().replace('###', version))
