@@ -1,4 +1,4 @@
-from PyQt5.QtWidgets import QDialog, QTableWidgetItem, QHeaderView
+from PyQt5.QtWidgets import QDialog, QTableWidgetItem, QHeaderView, QApplication
 
 from motorlib.simResult import alertLevelNames, alertTypeNames
 
@@ -10,6 +10,8 @@ class SimulationAlertsDialog(QDialog):
         self.ui = Ui_SimAlertsDialog()
         self.ui.setupUi(self)
 
+        self.setWindowIcon(QApplication.instance().icon)
+
         header = self.ui.tableWidgetAlerts.horizontalHeader()
         header.setSectionResizeMode(0, QHeaderView.ResizeToContents)
         header.setSectionResizeMode(1, QHeaderView.ResizeToContents)
@@ -20,11 +22,13 @@ class SimulationAlertsDialog(QDialog):
 
     def displayAlerts(self, simRes):
         self.ui.tableWidgetAlerts.setRowCount(0) # Clear the table
-        if len(simRes.alerts) > 0:
-            self.ui.tableWidgetAlerts.setRowCount(len(simRes.alerts))
-            for row, alert in enumerate(simRes.alerts):
-                self.ui.tableWidgetAlerts.setItem(row, 0, QTableWidgetItem(alertLevelNames[alert.level]))
-                self.ui.tableWidgetAlerts.setItem(row, 1, QTableWidgetItem(alertTypeNames[alert.type]))
-                self.ui.tableWidgetAlerts.setItem(row, 2, QTableWidgetItem(alert.location))
-                self.ui.tableWidgetAlerts.setItem(row, 3, QTableWidgetItem(alert.description))
-            self.show()
+        if len(simRes.alerts) == 0:
+            return
+
+        self.ui.tableWidgetAlerts.setRowCount(len(simRes.alerts))
+        for row, alert in enumerate(simRes.alerts):
+            self.ui.tableWidgetAlerts.setItem(row, 0, QTableWidgetItem(alertLevelNames[alert.level]))
+            self.ui.tableWidgetAlerts.setItem(row, 1, QTableWidgetItem(alertTypeNames[alert.type]))
+            self.ui.tableWidgetAlerts.setItem(row, 2, QTableWidgetItem(alert.location))
+            self.ui.tableWidgetAlerts.setItem(row, 3, QTableWidgetItem(alert.description))
+        self.show()
